@@ -24,7 +24,6 @@ import org.gcube.portlets.widgets.ckandatapublisherwidget.client.ui.resources.Ad
 import org.gcube.portlets.widgets.ckandatapublisherwidget.client.ui.resources.ManageResources;
 import org.gcube.portlets.widgets.ckandatapublisherwidget.client.ui.utils.InfoIconsLabels;
 import org.gcube.portlets.widgets.ckandatapublisherwidget.client.ui.utils.WizardCreator;
-import org.gcube.portlets.widgets.ckandatapublisherwidget.client.ui.workspace.SelectResourceByWEMainPanel;
 import org.gcube.portlets.widgets.ckandatapublisherwidget.shared.DatasetBean;
 import org.gcube.portlets.widgets.ckandatapublisherwidget.shared.MetadataProfileBeanForUpdate;
 import org.gcube.portlets.widgets.ckandatapublisherwidget.shared.OrganizationBean;
@@ -310,7 +309,7 @@ public class UpdateDatasetForm extends Composite {
 	private DatasetBean theDatasetBean;
 
 	// resource table
-	private SelectResourceByWEMainPanel resourcesSelectByWEMainPanel;
+	//private SelectResourceByWEMainPanel resourcesSelectByWEMainPanel;
 
 	// List of opened popup'ids
 	private List<String> popupOpenedIds = new ArrayList<String>();
@@ -515,11 +514,11 @@ public class UpdateDatasetForm extends Composite {
 								// set it as visible anyway
 								tagsPanel.setVisible(true);
 
-								// The resource root is the folder id. Es. ID of the Workspace Root folder.
-								if (datasetBean.getResourceRoot() != null) {
-									resourcesSelectByWEMainPanel = new SelectResourceByWEMainPanel(
-											datasetBean.getResourceRoot());
-								}
+//								// The resource root is the folder id. Es. ID of the Workspace Root folder.
+//								if (datasetBean.getResourceRoot() != null) {
+//									resourcesSelectByWEMainPanel = new SelectResourceByWEMainPanel(
+//											datasetBean.getResourceRoot());
+//								}
 
 								// set organizations
 								List<OrganizationBean> organizations = datasetBean.getOrganizationList();
@@ -946,7 +945,7 @@ public class UpdateDatasetForm extends Composite {
 			// add the resources to the container panel
 			if (workspaceResourcesContainer.getWidget() == null) {
 				workspaceResourcesContainer.getElement().getStyle().setMarginLeft(20, Unit.PX);
-				workspaceResourcesContainer.add(resourcesSelectByWEMainPanel);
+				//workspaceResourcesContainer.add(resourcesSelectByWEMainPanel);
 			}
 
 		} else {
@@ -1156,9 +1155,9 @@ public class UpdateDatasetForm extends Composite {
 			theDatasetBean.setGroups(groups);
 			theDatasetBean.setGroupsForceCreation(groupsToForceCreation);
 
-			if (resourcesSelectByWEMainPanel != null) {
-				theDatasetBean.setResourceRoot(resourcesSelectByWEMainPanel.getResourcesToPublish());
-			}
+//			if (resourcesSelectByWEMainPanel != null) {
+//				theDatasetBean.setResourceRoot(resourcesSelectByWEMainPanel.getResourcesToPublish());
+//			}
 
 			theDatasetBean.setCustomFields(customFieldsMap);
 
@@ -1600,9 +1599,9 @@ public class UpdateDatasetForm extends Composite {
 
 		}
 
-		// freeze table of resources
-		if (resourcesSelectByWEMainPanel != null)
-			resourcesSelectByWEMainPanel.freeze();
+//		// freeze table of resources
+//		if (resourcesSelectByWEMainPanel != null)
+//			resourcesSelectByWEMainPanel.freeze();
 	}
 
 	/**
